@@ -5,19 +5,21 @@ from .queries import filtr
 from .queries import join
 from .queries import request
 from .queries import select
+from .queries import setwhere
 from .queries import summarize
 from .queries import update
 from .wrapper import Querier
 
 __all__ = [
-    concat,
-    delete,
-    drop,
-    filtr,
-    join,
-    request,
-    select,
-    summarize,
-    update,
-    Querier,
+    "concat",
+    "delete",
+    "drop",
+    "filtr",
+    "join",
+    "request",
+    "select",
+    "setwhere",
+    "summarize",
+    "update",
+    "Querier",
 ]
