@@ -5,6 +5,7 @@ from .filtr import filtr
 from .join import join
 from .request import request
 from .select import select
+from .set import setwhere
 from .summarize import summarize
 from .update import update
 
@@ -17,6 +18,7 @@ __all__ = [
     join,
     request,
     select,
+    setwhere,
     summarize,
     update,
 ]
